//
//  YHMyWorkExperienceCell.swift
//  galaxy
//
//  Created by edy on 2024/6/18.
//  Copyright © 2024 https://www.galaxy-immi.com. All rights reserved.
//

import UIKit

class YHExperienceItemView: UIView {
    
    lazy var titleLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor50
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:14)
        return label
    }()
    
    lazy var detailLabel:UILabel = {
        let label = UILabel()
        label.textColor = UIColor.mainTextColor70
        label.textAlignment = .left
        label.font = UIFont.PFSC_R(ofSize:14)
        return label
    }()
    
    override init(frame: CGRect) {
        super.init(frame: frame)
        createUI()
    }
    
    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }
    
    func createUI() {
        self.addSubview(self.titleLabel)
        self.addSubview(self.detailLabel)
        self.titleLabel.snp.makeConstraints { make in
            make.left.equalTo(0)
            make.width.equalTo(56)
            make.height.equalTo(20)
            make.centerY.equalToSuperview()
        }
        self.detailLabel.snp.makeConstraints { make in
            make.left.equalTo(self.titleLabel.snp.right).offset(56)
            make.right.equalToSuperview()
            make.centerY.equalToSuperview()
        }
    }
}

class YHMyWorkExperienceCell: UITableViewCell {

    static let cellReuseIdentifier = "YHMyWorkExperienceCell"

    lazy var cardView: UIView = {
        let view = UIView()
        view.backgroundColor = .white
        view.layer.cornerRadius = 3.0
        view.clipsToBounds = true
        return view
    }()
    
    lazy var titleLabel:UILabel = {
        let label = UILabel()
        label.text = "工作经历"
        label.textColor = UIColor(hexString: "#222222")
        label.textAlignment = .left
        label.font = UIFont.PFSC_M(ofSize:17)
        return label
    }()
    
    lazy var editBtn:UIButton = {
        let btn = UIButton()
        btn.setImage(UIImage(named: "people_card_edit"), for: .normal)
        btn.YH_clickEdgeInsets = UIEdgeInsets(top: 20, left: 20, bottom: 20, right: 20)
        return btn
    }()
    
    lazy var companyView:YHExperienceItemView = {
        let view = YHExperienceItemView()
        view.titleLabel.text = "所在企业"
        return view
    }()
    
    lazy var professionView:YHExperienceItemView = {
        let view = YHExperienceItemView()
        view.titleLabel.text = "职位"
        return view
    }()
    
    lazy var industryView:YHExperienceItemView = {
        let view = YHExperienceItemView()
        view.titleLabel.text = "所在行业"
        return view
    }()
    
    required init?(coder: NSCoder) {
        super.init(coder: coder)
    }
    
    override init(style: UITableViewCell.CellStyle, reuseIdentifier: String?) {
        super.init(style: style, reuseIdentifier: reuseIdentifier)
        setupUI()
    }
    
    func setupUI() {
        
        self.selectionStyle = .none
        self.backgroundColor = .clear
        self.contentView.backgroundColor = .clear
        
        self.contentView.addSubview(self.cardView)
        cardView.addSubview(self.titleLabel)
        cardView.addSubview(self.editBtn)
        cardView.addSubview(self.companyView)
        cardView.addSubview(self.professionView)
        cardView.addSubview(self.industryView)

        cardView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        titleLabel.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.top.equalTo(16)
            make.height.equalTo(24)
        }
        
        editBtn.snp.makeConstraints { make in
            make.width.height.equalTo(20)
            make.right.equalTo(-15)
            make.centerY.equalTo(titleLabel)
        }
        
        companyView.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.height.equalTo(20)
            make.top.equalTo(self.titleLabel.snp.bottom).offset(12)
        }
        
        professionView.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.height.equalTo(20)
            make.top.equalTo(self.companyView.snp.bottom).offset(14)
        }
        
        industryView.snp.makeConstraints { make in
            make.left.equalTo(16)
            make.right.equalTo(-16)
            make.height.equalTo(20)
            make.top.equalTo(self.professionView.snp.bottom).offset(14)
            make.bottom.equalToSuperview().offset(-16)
        }
        
    }

}
